import React, { useEffect, useState } from 'react';
import { connect, history } from 'umi';
import ProCard from '@ant-design/pro-card';
import { PageContainer } from '@ant-design/pro-layout';
import Container from '@/components/Container';
import { Input, Select, Form, Button, notification } from 'antd';
import ProForm, { ProFormText, ProFormTextArea, ProFormSelect } from '@ant-design/pro-form';
import request from '@/utils/request';

const { Option } = Select;
const { Search } = Input;
const VisitEdit = (props) => {
  const { id, schoolId } = props.location.query;
  const [list, setList] = useState([]);
  const [searchLoading, setSearchLoading] = useState(false);

  const [form] = Form.useForm();

  const getData = (id) => {
    if (id) {
      request(`/student/${id}`)
        .then((res) => {
          console.log(res, 'res');
          form.setFieldsValue(res);
          setSearchLoading(false);
        })
        .catch((e) => {
          setSearchLoading(false);
        });
    } else {
      // this.setState({ data: [] });
    }
  };

  useEffect(()=>{
if(id){
  if (id) {
    request(`/medical-log/${id}`)
      .then((res) => {
        console.log(res, 'res');
        form.setFieldsValue(res);
        setSearchLoading(false);
      })
      .catch((e) => {
        setSearchLoading(false);
      });
  } else {
    // this.setState({ data: [] });
  }
}
  },[id])

  const onSearch = (value) => {
    if (value) {
      getData(value);
      setSearchLoading(true);
    } else {
      // this.setState({ data: [] });
    }
  };

  const handleChange = (value) => {
    // this.setState({ value });
  };
  const handleSubmit = (value) => {
    // this.setState({ value });
    console.log(value, 'handleSubmit');
    request('/medicalLog', { method: 'post', data: {schoolId, ...value } })
    .then(() => {

      notification.success({ message: '新建成功' });
      history.go('-1')
    })
    .catch((e) => {
      notification.error({ message: e.message });
    });
  };
  return (
    <PageContainer
      header={{
        extra: [
          <Button key="1" onClick={() => history.go('-1')}>
            返回
          </Button>,
        ],
      }}
    >
      <Container>
        <ProForm form={form} submitter={!id} onFinish={handleSubmit}>
          <ProCard.Group title="就诊信息" bodyStyle={{ padding: 20 }}>
            {!id && (
              <Search
                placeholder="请输入学号"
                loading={searchLoading}
                style={{ width: 200, marginBottom: '20px' }}
                onSearch={onSearch}
              />
            )}

            <ProFormText
              label="姓名"
              placeholder="输入名称"
              name="name"
              fieldProps={{ bordered: !id, readOnly: !!id }}
              rules={[{ required: true, message: '请填写名称' }]}
            />

            <ProFormSelect
              options={[
                {
                  value: 1,
                  label: '男',
                },
                {
                  value: 2,
                  label: '女',
                },
              ]}
              name="sex"
              label="性别"
              fieldProps={{ bordered: !id, open: id ? false : undefined }}
              rules={[{ required: true, message: '请选择性别' }]}
            />

            <ProFormText
              label="学号"
              placeholder="输入学号"
              name="studentId"
              fieldProps={{ bordered: !id, readOnly: !!id }}
              rules={[{ required: true, message: '请填写学号' }]}
            />

            <ProFormText
              label="联系方式"
              placeholder="输入联系方式"
              name="phone"
              fieldProps={{ bordered: !id, readOnly: !!id }}
              rules={[{ required: true, message: '请填写联系方式' }]}
            />
          </ProCard.Group>
          <ProCard.Group title="诊断" bodyStyle={{ padding: 20 }}>
            <ProFormSelect
              label="就诊科室"
              placeholder="输选择"
              name="hospitalId"
              fieldProps={{ bordered: !id, open: id ? false : undefined }}
              request={async ({ keyWords }) => {
                // console.log()
                // if (keyWords) {
                return request('/hospital', {
                  method: 'get',
                  params: { name: keyWords, schoolId, pageNum: 1, pageSize: 1000 },
                })
                  .then((res) => {
                    return res?.records?.map((x) => {
                      return { label: x.name, value: x.hospitalId };
                    });
                  })
                  .catch((e) => {
                    return Promise.reject(e.message);
                  });
                // }
              }}
              rules={[{ required: true, message: '请选择科室' }]}
            />

            <ProFormTextArea
              label="诊断报告"
              placeholder="输入诊断报告"
              name="attchment"
             
              fieldProps={{readOnly: !!id }}
              rules={[{ required: true, message: '请填写诊断报告' }]}
            />
          </ProCard.Group>
        </ProForm>
      </Container>
    </PageContainer>
  );
};

export default connect((s) => ({
  typeList: s.post.typeList,
}))(VisitEdit);
