import React, { useRef,useState, useCallback } from 'react';
import { connect, history } from 'umi';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import { PlusOutlined } from '@ant-design/icons';
import { Button,  Space } from 'antd';
import  { queryTable } from '@/utils/request';
import School from '@/components/School';

const VisitList = () => {


  const ref = useRef();
  const [school, setSchool] = useState({});

  const handleMedicalClick = (id) => {
    console.log(school,'school')
    history.push(id ? `/medical/visit/edit?id=${id}&schoolId=${school?.schoolId}` : `/medical/visit/edit?schoolId=${school?.schoolId}`);
  }

  const actions = [   
    <Button key="button" icon={<PlusOutlined />} type="primary" onClick={() => handleMedicalClick()}>
      新建
    </Button>,
  ];

  const queryFunc = (params, page, sort, filter) => {
    if (!school.schoolId) {
      return Promise.resolve({ data: [], success: true, total: 0 });
    }
    console.log(school,'queryFunc')
    const newParams = { ...params, schoolId: school.schoolId };
    return queryTable('/medicalLog')(newParams, page, sort, filter);
  };

  const renderFormItem = (item, config, form) => {
    const handleSchoolChange = (schoolId, schoolInfo) => {
      form.setFieldsValue({ schoolId });
      form.submit();
      console.log(schoolInfo,'schoolInfo')
      setSchool({...schoolInfo});
    };

    return <School onChange={handleSchoolChange} />;
  };

  const columns = [
    {
      title: '就诊编号',
      dataIndex: 'serialNo',
      hideInSearch: true,

      align: 'center',
    },
    {
      title: '所属学校',
      key: 'schoolId',
      dataIndex: 'schoolId',
      valueType: 'select',
      renderFormItem,
    },

    {
      title: '学号',
      dataIndex: 'd',
      align: 'center',
     
    },
    {
      title: '姓名',
      dataIndex: 'status',
      align: 'center',
      hideInSearch: true,
      // hideInTable: true,
    },
    {
      title: '性别',
      dataIndex: 'status',
      align: 'center',
      hideInSearch: true,
    },
    {
      title: '专业',
      dataIndex: 'status',
      align: 'center',
      // hideInTable: true,
    },
    {
      title: '医生',
      dataIndex: 'createDate',
      align: 'center',
      hideInSearch: true,
      valueType: 'date',
    },
    {
      title: '就诊科室',
      dataIndex: 'createDate',
      align: 'center',
      hideInSearch: true,

    },
    {
      title: '就诊时间',
      dataIndex: 'recordDate',
      align: 'center',
      hideInSearch: true,
      valueType: 'date',
    },
    
    {
      title: '操作',
      dataIndex: 'action',
      align: 'center',
      hideInSearch: true,
      render: (text, record) => (
        <Space size="middle">
          <a onClick={() => handleMedicalClick(record.serialNo)}>查看报告</a>
         
        </Space>
      ),
    },
  ];

  return (
    <PageContainer>
      <ProTable
        columns={columns}
        request={queryFunc}
        formRef={ref}
        rowKey="serialNo"
        headerTitle="就诊列表"
        search={{
          labelWidth: '4em',
        }}
        toolBarRender={() => actions}
      />
    </PageContainer>
  );
};

export default connect((s) => ({
  typeList: s.post.typeList,
}))(VisitList);
