import React, { useEffect, useMemo, useRef, useState } from 'react';
import { connect } from 'umi';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import request, { queryTable } from '@/utils/request';

const StudentData = (props) => {
  const tableRef = useRef()
  const [schoolDict, setSchoolDict] = useState({})

  const columns = useMemo(() => [
    {
      title: '排名',
      key: 'topN',
      hideInSearch: true,
      render: (_, $, index) => index + 1,
    },
    {
      title: '学校',
      key: 'schoolId',
      dataIndex: 'schoolId',
      valueType: 'select',
      valueEnum: schoolDict,
    },
    {
      title: '名称',
      key: 'name',
      dataIndex: 'name',
    },
    {
      title: '手机号',
      key: 'phone',
      dataIndex: 'phone',
      hideInSearch: true,
    },
    {
      title: '收藏文章数',
      key: 'savedNum',
      dataIndex: 'savedNum',
      hideInSearch: true,
      sorter: true,
    },
    {
      title: '阅读文章数',
      key: 'readedNum',
      dataIndex: 'readedNum',
      hideInSearch: true,
      sorter: true,
    },
    {
      title: '总积分',
      key: 'pointNum',
      dataIndex: 'pointNum',
      hideInSearch: true,
      sorter: true,
    },
    {
      title: '学分',
      key: 'creditNum',
      dataIndex: 'creditNum',
      hideInSearch: true,
      sorter: true,
    },
  ], [schoolDict])

  useEffect(() => {
    request('/school', { params: { pageSize: 500 } }).then(res => {
      const records = res.records || []
      const dict = records.reduce((acc, item) => {
        return {
          ...acc,
          [item.schoolId]: { text: item.name },
        };
      }, {})
      setSchoolDict(dict)
    }).catch((e) => {
      // eslint-disable-next-line
      console.error(e.message)
    })

  // eslint-disable-next-line
  }, [])

  return (
    <PageContainer>
      <ProTable
        actionRef={tableRef}
        columns={columns}
        request={queryTable('/statis/student-data')}
        rowKey="personId"
        search={{
          labelWidth: '4em',
        }}
        options={false}
      />
    </PageContainer>
  );
};

export default connect((s) => ({
  user: s.user.currentUser,
}))(StudentData);
