import React, { useEffect } from 'react';
import ProForm, { ProFormText } from '@ant-design/pro-form';
import request from '@/utils/request';
import { notification, Form } from 'antd';

export default (props) => {
  const [form] = Form.useForm();

  const handleSubmit = (values) => {
    const data = {
      ...props.role || {},
      ...values,
    }

    if (!data.roleId) {
      // 新增
      return request('/role', { method: 'post', data })
        .then((res) => {
          notification.success({ message: '操作成功' });
          props.onChange(res);
        })
        .catch((e) => {
          notification.error({ message: e.message });
          return Promise.reject(e.message);
        });
    }

    // 编辑
    return request(`/role/${data.roleId}`, { method: 'put', data })
    .then((res) => {
      notification.success({ message: '操作成功' });
      props.onChange(res);
    })
    .catch((e) => {
      notification.error({ message: e.message });
      return Promise.reject(e.message);
    });
  };

  useEffect(() => {
    if (props.role && props.role.roleId) {
      form.setFieldsValue(props.role);
    }
  }, [props, form]);

  return (
    <ProForm form={form} onFinish={handleSubmit}>
      <ProFormText
        label="角色名称"
        placeholder="请输入角色名称"
        name="name"
        rules={[{ required: true, message: '请填写角色名称' }]}
      />
      <ProFormText label="创建日期" name="createDate" readonly />
    </ProForm>
  );
};
