import React, { useRef } from 'react'
import { history } from 'umi';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import { PlusOutlined } from '@ant-design/icons';
import { Button, Popconfirm, notification } from 'antd';
import request, { queryTable } from '@/utils/request';

export default () => {
  const tableRef = useRef()

  const handleDelete = (role) => {
    request(`/role/${role.roleId}`, { method: 'delete' } ).then(() => {
      notification.success({ message: '操作成功' })
      tableRef.current.reload()
    }).catch((e) => {
      notification.error({ message: e.message })
    })
  }

  const handleEdit = (role) => {
    const url = role && role.roleId ? `/system/role/edit?id=${role.roleId}` : '/system/role/edit'
    history.push(url)
  }

  const columns = [
    {
      title: '名称',
      key: 'name',
      dataIndex: 'name',
    },
    {
      title: '创建时间',
      key: 'createDate',
      dataIndex: 'createDate',
      valueType: 'date',
      width: 360,
    },
    {
      title: '操作',
      key: 'option',
      valueType: 'option',
      width: 240,
      // 不能操作超级管理员
      render: (_, role) => [
        role.roleId !== '1' && <a key="edit" onClick={() => handleEdit(role)}>修改</a>,
        role.roleId !== '1' && <Popconfirm key="delete" title="确定删除当前角色?" onConfirm={() => handleDelete(role)}>
          <a href="#">删除</a>
        </Popconfirm>,
      ].filter(Boolean)
    },
  ]
  
  const actions = [
    <Button key="button" icon={<PlusOutlined />} type="primary" onClick={handleEdit}>
      新建
    </Button>,
  ];

  return (
    <PageContainer>
      <ProTable
        actionRef={tableRef}
        columns={columns}
        request={queryTable('/role')}
        rowKey="roleId"
        headerTitle="角色列表"
        search={false}
        toolBarRender={() => actions}
      />
    </PageContainer>
  )
}
